==> rsyslog-8.33.1.tar.gz: rsyslog-8.33.1/tests/mmanon_random_cons_128_ipembedded.sh <==
#!/bin/bash
# add 2016-11-22 by Jan Gerhards, released under ASL 2.0
. $srcdir/diag.sh init
. $srcdir/diag.sh generate-conf
. $srcdir/diag.sh add-conf '
template(name="outfmt" type="string" string="%msg%\n")
template(name="filename" type="string" string="rsyslog.out.%syslogtag%.log")

module(load="../plugins/mmanon/.libs/mmanon")
module(load="../plugins/imtcp/.libs/imtcp")
input(type="imtcp" port="13514" ruleset="testing")

ruleset(name="testing") {
	action(type="mmanon" ipv6.enable="off" ipv4.enable="off" embeddedipv4.anonmode="random-consistent" embeddedipv4.bits="128")
	action(type="omfile" dynafile="filename" template="outfmt")
}'

echo 'Since this test tests randomization, there is a theoretical possibility of it failing even if rsyslog works correctly. Therefore, if the test unexpectedly fails try restarting it.'
. $srcdir/diag.sh startup
. $srcdir/diag.sh tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 file1 33:45:DDD::4.123.123.3
<129>Mar 10 01:00:00 172.20.245.8 file2 ::0.0.0.0
<129>Mar 10 01:00:00 172.20.245.8 file6 ::0.0.0.0
<129>Mar 10 01:00:00 172.20.245.8 file3 72:8374:adc7:47FF::43:0.34.225.1
<129>Mar 10 01:00:00 172.20.245.8 file4 FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:255.255.255.255
<129>Mar 10 01:00:00 172.20.245.8 file5 72:8374:adc7:47FF::43:0.34.225.1\""

. $srcdir/diag.sh shutdown-when-empty
. $srcdir/diag.sh wait-shutdown
echo ' 33:45:DDD::4' | cmp - rsyslog.out.file1.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file1.log is:"
  cat rsyslog.out.file1.log
  . $srcdir/diag.sh error-exit  1
fi;

echo ' ::' | cmp - rsyslog.out.file2.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file2.log is:"
  cat rsyslog.out.file2.log
  . $srcdir/diag.sh error-exit  1
fi;

echo ' 72:8374:adc7:47FF::43:0:1AFE' | cmp - rsyslog.out.file3.log  >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file3.log is:"
  cat rsyslog.out.file3.log
  . $srcdir/diag.sh error-exit  1
fi;

echo ' FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF' | cmp - rsyslog.out.file4.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file4.log is:"
  cat rsyslog.out.file4.log
  . $srcdir/diag.sh error-exit  1
fi;

cmp rsyslog.out.file3.log rsyslog.out.file5.log >/dev/null
if [ ! $? -eq 0 ]; then
  echo "invalidly unequal ip-addresses generated, rsyslog.out.file3.log and rsyslog.out.file5.log are:"
  cat rsyslog.out.file3.log
  cat rsyslog.out.file5.log
  . $srcdir/diag.sh error-exit  1
fi;

cmp rsyslog.out.file2.log rsyslog.out.file6.log >/dev/null
if [ ! $? -eq 0 ]; then
  echo "invalidly unequal ip-addresses generated, rsyslog.out.file1.log and rsyslog.out.file6.log are:"
  cat rsyslog.out.file1.log
  cat rsyslog.out.file6.log
  . $srcdir/diag.sh error-exit  1
fi;

cmp rsyslog.out.file4.log rsyslog.out.file5.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-addresses generated, rsyslog.out.file4.log and rsyslog.out.file5.log are:"
  cat rsyslog.out.file4.log
  cat rsyslog.out.file5.log
  . $srcdir/diag.sh error-exit  1
fi;

. $srcdir/diag.sh exit

==> rsyslog-8.37.0.tar.gz: rsyslog-8.37.0/tests/mmanon_random_cons_128_ipembedded.sh <==
#!/bin/bash
# add 2016-11-22 by Jan Gerhards, released under ASL 2.0
. $srcdir/diag.sh init
generate_conf
add_conf '
template(name="outfmt" type="string" string="%msg%\n")
template(name="filename" type="string" string="rsyslog.out.%syslogtag%.log")

module(load="../plugins/mmanon/.libs/mmanon")
module(load="../plugins/imtcp/.libs/imtcp")
input(type="imtcp" port="13514" ruleset="testing")

ruleset(name="testing") {
	action(type="mmanon" ipv6.enable="off" ipv4.enable="off" embeddedipv4.anonmode="random-consistent" embeddedipv4.bits="128")
	action(type="omfile" dynafile="filename" template="outfmt")
}'

echo 'Since this test tests randomization, there is a theoretical possibility of it failing even if rsyslog works correctly. Therefore, if the test unexpectedly fails try restarting it.'
startup
tcpflood -m1 -M "\"<129>Mar 10 01:00:00 172.20.245.8 file1 33:45:DDD::4.123.123.3
<129>Mar 10 01:00:00 172.20.245.8 file2 ::0.0.0.0
<129>Mar 10 01:00:00 172.20.245.8 file6 ::0.0.0.0
<129>Mar 10 01:00:00 172.20.245.8 file3 72:8374:adc7:47FF::43:0.34.225.1
<129>Mar 10 01:00:00 172.20.245.8 file4 FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:255.255.255.255
<129>Mar 10 01:00:00 172.20.245.8 file5 72:8374:adc7:47FF::43:0.34.225.1\""

shutdown_when_empty
wait_shutdown
echo ' 33:45:DDD::4' | cmp - rsyslog.out.file1.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file1.log is:"
  cat rsyslog.out.file1.log
  error_exit  1
fi;

echo ' ::' | cmp - rsyslog.out.file2.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file2.log is:"
  cat rsyslog.out.file2.log
  error_exit  1
fi;

echo ' 72:8374:adc7:47FF::43:0:1AFE' | cmp - rsyslog.out.file3.log  >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file3.log is:"
  cat rsyslog.out.file3.log
  error_exit  1
fi;

echo ' FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF' | cmp - rsyslog.out.file4.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-address generated, rsyslog.out.file4.log is:"
  cat rsyslog.out.file4.log
  error_exit  1
fi;

cmp rsyslog.out.file3.log rsyslog.out.file5.log >/dev/null
if [ ! $? -eq 0 ]; then
  echo "invalidly unequal ip-addresses generated, rsyslog.out.file3.log and rsyslog.out.file5.log are:"
  cat rsyslog.out.file3.log
  cat rsyslog.out.file5.log
  error_exit  1
fi;

cmp rsyslog.out.file2.log rsyslog.out.file6.log >/dev/null
if [ ! $? -eq 0 ]; then
  echo "invalidly unequal ip-addresses generated, rsyslog.out.file1.log and rsyslog.out.file6.log are:"
  cat rsyslog.out.file1.log
  cat rsyslog.out.file6.log
  error_exit  1
fi;

cmp rsyslog.out.file4.log rsyslog.out.file5.log >/dev/null
if [ ! $? -eq 1 ]; then
  echo "invalidly equal ip-addresses generated, rsyslog.out.file4.log and rsyslog.out.file5.log are:"
  cat rsyslog.out.file4.log
  cat rsyslog.out.file5.log
  error_exit  1
fi;

exit_test
